@@ -321,7 +321,7 @@ class OracleHook(DbApiHook):
         target_fields: list[str] | None = None,
         commit_every: int = 5000,
     ):
-        """A performant bulk insert for Oracle DB.
+        """Perform bulk inserts efficiently for Oracle DB.
 
         This uses prepared statements via `executemany()`. For best performance,
         pass in `rows` as an iterator.
